==> redshift-0.8.0-sources.jar: software/amazon/awscdk/services/redshift/cloudformation/ClusterParameterGroupResource.java <==
package software.amazon.awscdk.services.redshift.cloudformation;
/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html
 */
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.redshift.$Module.class, fqn = "@aws-cdk/aws-redshift.cloudformation.ClusterParameterGroupResource")
public class ClusterParameterGroupResource extends software.amazon.awscdk.Resource {
    protected ClusterParameterGroupResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.redshift.cloudformation.ClusterParameterGroupResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::Redshift::ClusterParameterGroup``.
     * @param parent the ``cdk.Construct`` this ``ClusterParameterGroupResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``ClusterParameterGroupResource``
     */
    public ClusterParameterGroupResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.redshift.cloudformation.ClusterParameterGroupResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html
     */
    public static interface ParameterProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
         */
        java.lang.Object getParameterName();
        /**
         * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
         */
        void setParameterName(final java.lang.String value);
        /**
         * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
         */
        void setParameterName(final software.amazon.awscdk.Token value);
        /**
         * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
         */
        java.lang.Object getParameterValue();
        /**
         * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
         */
        void setParameterValue(final java.lang.String value);
        /**
         * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
         */
        void setParameterValue(final software.amazon.awscdk.Token value);

        // ==================================================================
        // Builder
        // ==================================================================

        static Builder builder() {
            return new Builder();
        }
        /**
         * A fluent step builder class for {@link ParameterProperty}.
         * The {@link Build#build()} method will be available once all required properties are fulfilled.
         */
        final class Builder {
            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
             */
            public ParameterValueStep withParameterName(final java.lang.String value) {
                return new FullBuilder().withParameterName(value);
            }
            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
             */
            public ParameterValueStep withParameterName(final software.amazon.awscdk.Token value) {
                return new FullBuilder().withParameterName(value);
            }

            public interface ParameterValueStep {
                /**
                 * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
                 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
                 */
                Build withParameterValue(final java.lang.String value);
                /**
                 * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
                 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
                 */
                Build withParameterValue(final software.amazon.awscdk.Token value);
            }

            public interface Build {
                /**
                 * @return a new {@link ParameterProperty} object, initialized with the values set on this builder.
                 */
                ParameterProperty build();
            }

            final class FullBuilder implements ParameterValueStep, Build {

                private Jsii$Pojo instance = new Jsii$Pojo();

                /**
                 * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
                 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
                 */
                public ParameterValueStep withParameterName(final java.lang.String value) {
                    java.util.Objects.requireNonNull(value, "ParameterProperty#parameterName is required");
                    this.instance._parameterName = value;
                    return this;
                }
                /**
                 * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
                 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
                 */
                public ParameterValueStep withParameterName(final software.amazon.awscdk.Token value) {
                    java.util.Objects.requireNonNull(value, "ParameterProperty#parameterName is required");
                    this.instance._parameterName = value;
                    return this;
                }
                /**
                 * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
                 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
                 */
                public Build withParameterValue(final java.lang.String value) {
                    java.util.Objects.requireNonNull(value, "ParameterProperty#parameterValue is required");
                    this.instance._parameterValue = value;
                    return this;
                }
                /**
                 * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
                 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
                 */
                public Build withParameterValue(final software.amazon.awscdk.Token value) {
                    java.util.Objects.requireNonNull(value, "ParameterProperty#parameterValue is required");
                    this.instance._parameterValue = value;
                    return this;
                }
                public ParameterProperty build() {
                    ParameterProperty result = this.instance;
                    this.instance = new Jsii$Pojo();
                    return result;
                }
            }
        }

        /**
         * A PoJo (plain-old-java-object) class that implements {@link ParameterProperty}.
         */
        final class Jsii$Pojo implements ParameterProperty {

            /**
             * Constructor used by builders.
             */
            protected Jsii$Pojo() { }


            protected java.lang.Object _parameterName;

            public java.lang.Object getParameterName() {
                return this._parameterName;
            }
            public void setParameterName(final java.lang.String value) {
                this._parameterName = value;
            }
            public void setParameterName(final software.amazon.awscdk.Token value) {
                this._parameterName = value;
            }

            protected java.lang.Object _parameterValue;

            public java.lang.Object getParameterValue() {
                return this._parameterValue;
            }
            public void setParameterValue(final java.lang.String value) {
                this._parameterValue = value;
            }
            public void setParameterValue(final software.amazon.awscdk.Token value) {
                this._parameterValue = value;
            }
        }

        /**
         * A proxy class which for javascript object literal which adhere to this interface.
         */
        class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.redshift.cloudformation.ClusterParameterGroupResource.ParameterProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }
            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
             */
            public java.lang.Object getParameterName() {
                return this.jsiiGet("parameterName", java.lang.Object.class);
            }
            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
             */
            public void setParameterName(final java.lang.String value) {
                this.jsiiSet("parameterName", java.util.Objects.requireNonNull(value, "parameterName is required"));
            }
            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
             */
            public void setParameterName(final software.amazon.awscdk.Token value) {
                this.jsiiSet("parameterName", java.util.Objects.requireNonNull(value, "parameterName is required"));
            }
            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
             */
            public java.lang.Object getParameterValue() {
                return this.jsiiGet("parameterValue", java.lang.Object.class);
            }
            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
             */
            public void setParameterValue(final java.lang.String value) {
                this.jsiiSet("parameterValue", java.util.Objects.requireNonNull(value, "parameterValue is required"));
            }
            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
             */
            public void setParameterValue(final software.amazon.awscdk.Token value) {
                this.jsiiSet("parameterValue", java.util.Objects.requireNonNull(value, "parameterValue is required"));
            }
        }
    }
}

==> redshift-0.9.0-sources.jar: software/amazon/awscdk/services/redshift/cloudformation/ClusterParameterGroupResource.java <==
package software.amazon.awscdk.services.redshift.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clusterparametergroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:55:13.590Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.redshift.$Module.class, fqn = "@aws-cdk/aws-redshift.cloudformation.ClusterParameterGroupResource")
public class ClusterParameterGroupResource extends software.amazon.awscdk.Resource {
    protected ClusterParameterGroupResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.redshift.cloudformation.ClusterParameterGroupResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::Redshift::ClusterParameterGroup``.
     * @param parent the ``cdk.Construct`` this ``ClusterParameterGroupResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``ClusterParameterGroupResource``
     */
    public ClusterParameterGroupResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.redshift.cloudformation.ClusterParameterGroupResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.redshift.ClusterParameterGroupName getRef() {
        return this.jsiiGet("ref", software.amazon.awscdk.services.redshift.ClusterParameterGroupName.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html
     */
    public static interface ParameterProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
         */
        java.lang.Object getParameterName();
        /**
         * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
         */
        void setParameterName(final java.lang.String value);
        /**
         * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
         */
        void setParameterName(final software.amazon.awscdk.CloudFormationToken value);
        /**
         * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
         */
        java.lang.Object getParameterValue();
        /**
         * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
         */
        void setParameterValue(final java.lang.String value);
        /**
         * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
         */
        void setParameterValue(final software.amazon.awscdk.CloudFormationToken value);

        /**
         * @return a {@link Builder} of {@link ParameterProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link ParameterProperty}
         */
        final class Builder {
            private java.lang.Object _parameterName;
            private java.lang.Object _parameterValue;

            /**
             * Sets the value of ParameterName
             * @param value ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
             * @return {@code this}
             */
            public Builder withParameterName(final java.lang.String value) {
                this._parameterName = java.util.Objects.requireNonNull(value, "parameterName is required");
                return this;
            }
            /**
             * Sets the value of ParameterName
             * @param value ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
             * @return {@code this}
             */
            public Builder withParameterName(final software.amazon.awscdk.CloudFormationToken value) {
                this._parameterName = java.util.Objects.requireNonNull(value, "parameterName is required");
                return this;
            }
            /**
             * Sets the value of ParameterValue
             * @param value ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
             * @return {@code this}
             */
            public Builder withParameterValue(final java.lang.String value) {
                this._parameterValue = java.util.Objects.requireNonNull(value, "parameterValue is required");
                return this;
            }
            /**
             * Sets the value of ParameterValue
             * @param value ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
             * @return {@code this}
             */
            public Builder withParameterValue(final software.amazon.awscdk.CloudFormationToken value) {
                this._parameterValue = java.util.Objects.requireNonNull(value, "parameterValue is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link ParameterProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public ParameterProperty build() {
                return new ParameterProperty() {
                    private java.lang.Object $parameterName = java.util.Objects.requireNonNull(_parameterName, "parameterName is required");
                    private java.lang.Object $parameterValue = java.util.Objects.requireNonNull(_parameterValue, "parameterValue is required");

                    @Override
                    public java.lang.Object getParameterName() {
                        return this.$parameterName;
                    }

                    @Override
                    public void setParameterName(final java.lang.String value) {
                        this.$parameterName = java.util.Objects.requireNonNull(value, "parameterName is required");
                    }

                    @Override
                    public void setParameterName(final software.amazon.awscdk.CloudFormationToken value) {
                        this.$parameterName = java.util.Objects.requireNonNull(value, "parameterName is required");
                    }

                    @Override
                    public java.lang.Object getParameterValue() {
                        return this.$parameterValue;
                    }

                    @Override
                    public void setParameterValue(final java.lang.String value) {
                        this.$parameterValue = java.util.Objects.requireNonNull(value, "parameterValue is required");
                    }

                    @Override
                    public void setParameterValue(final software.amazon.awscdk.CloudFormationToken value) {
                        this.$parameterValue = java.util.Objects.requireNonNull(value, "parameterValue is required");
                    }

                };
            }
        }

        /**
         * A proxy class which for javascript object literal which adhere to this interface.
         */
        final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.redshift.cloudformation.ClusterParameterGroupResource.ParameterProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
             */
            @Override
            public java.lang.Object getParameterName() {
                return this.jsiiGet("parameterName", java.lang.Object.class);
            }

            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
             */
            @Override
            public void setParameterName(final java.lang.String value) {
                this.jsiiSet("parameterName", java.util.Objects.requireNonNull(value, "parameterName is required"));
            }

            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametername
             */
            @Override
            public void setParameterName(final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("parameterName", java.util.Objects.requireNonNull(value, "parameterName is required"));
            }

            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
             */
            @Override
            public java.lang.Object getParameterValue() {
                return this.jsiiGet("parameterValue", java.lang.Object.class);
            }

            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
             */
            @Override
            public void setParameterValue(final java.lang.String value) {
                this.jsiiSet("parameterValue", java.util.Objects.requireNonNull(value, "parameterValue is required"));
            }

            /**
             * ``ClusterParameterGroupResource.ParameterProperty.ParameterValue``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-property-redshift-clusterparametergroup-parameter.html#cfn-redshift-clusterparametergroup-parameter-parametervalue
             */
            @Override
            public void setParameterValue(final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("parameterValue", java.util.Objects.requireNonNull(value, "parameterValue is required"));
            }
        }
    }
}
